@@ -1,7 +1,7 @@
 package Acme::CPANLists::PERLANCAR::Avoided;
 
 our $DATE = '2016-03-09'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 our @Module_Lists = (
     {
@@ -9,7 +9,12 @@ our @Module_Lists = (
         description => <<'_',
 
 This is a list of modules I'm currently avoiding to use in my code, for some
-reason.
+reason. Most of the modules wered used in my code in the past.
+
+Using a `Dist::Zilla` plugin `Dist::Zilla::Plugin::Acme::CPANLists::Blacklist`,
+you can make sure that during building, your distribution does not specify a
+prerequisite to any of the modules listed here. (You should make your own
+blacklist though).
 
 _
         entries => [
@@ -110,14 +115,19 @@ Acme::CPANLists::PERLANCAR::Avoided - Modules I'm currently avoiding
 
 =head1 VERSION
 
-This document describes version 0.12 of Acme::CPANLists::PERLANCAR::Avoided (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-03-09.
+This document describes version 0.13 of Acme::CPANLists::PERLANCAR::Avoided (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-03-09.
 
 =head1 MODULE LISTS
 
 =head2 Modules I'm currently avoiding
 
 This is a list of modules I'm currently avoiding to use in my code, for some
-reason.
+reason. Most of the modules wered used in my code in the past.
+
+Using a C<Dist::Zilla> plugin C<Dist::Zilla::Plugin::Acme::CPANLists::Blacklist>,
+you can make sure that during building, your distribution does not specify a
+prerequisite to any of the modules listed here. (You should make your own
+blacklist though).
 
 
 =over
