@@ -1,7 +1,7 @@
 package Acme::CPANLists::PERLANCAR::Retired;
 
 our $DATE = '2016-03-09'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 our @Module_Lists = (
     # list: Retired modules
@@ -9,10 +9,11 @@ our @Module_Lists = (
         summary => 'Retired modules',
         description => <<'_',
 
-This is a list of some of the modules which I wrote but have now been retired,
-for various reasons but mostly because they are no longer necessary. I've
-purged/retired more modules than these (mostly failed experiments) but they are
-not worth mentioning here because nobody else seems to have used them.
+This is a list of some of the modules which I wrote but have now been retired
+and purged from CPAN, for various reasons but mostly because they are no longer
+necessary. I've purged/retired more modules than these (mostly failed
+experiments) but they are not worth mentioning here because nobody else seems to
+have used them.
 
 Note that you can always get these retired modules from BackPAN or GitHub (I
 don't purge most of the repos) if needed.
@@ -23,7 +24,7 @@ _
                 module => 'Data::Schema',
                 description => <<'_',
 
-Superseded by `Data::Sah` since 2012.
+I wrote `Data::Sah` which superseded this module since 2012.
 
 _
                 alternate_modules => ['Data::Sah'],
@@ -43,8 +44,9 @@ _
                 module => 'Passwd::Unix::Alt',
                 description => <<'_',
 
-Abandoned this fork of `Passwd::Unix` due to a couple of fundamental issues and
-superseded by `Unix::Passwd::File` which is a clean-slate attempt.
+I first wrote `Passwd::Unix::Alt` (a fork of `Passwd::Unix`) to support shadow
+passwd/group files, but later abandoned this fork due to a couple of fundamental
+issues and later wrote a clean-slate attempt `Unix::Passwd::File`.
 
 _
                 alternate_modules => ['Unix::Passwd::File'],
@@ -68,16 +70,17 @@ Acme::CPANLists::PERLANCAR::Retired - Retired modules
 
 =head1 VERSION
 
-This document describes version 0.12 of Acme::CPANLists::PERLANCAR::Retired (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-03-09.
+This document describes version 0.13 of Acme::CPANLists::PERLANCAR::Retired (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-03-09.
 
 =head1 MODULE LISTS
 
 =head2 Retired modules
 
-This is a list of some of the modules which I wrote but have now been retired,
-for various reasons but mostly because they are no longer necessary. I've
-purged/retired more modules than these (mostly failed experiments) but they are
-not worth mentioning here because nobody else seems to have used them.
+This is a list of some of the modules which I wrote but have now been retired
+and purged from CPAN, for various reasons but mostly because they are no longer
+necessary. I've purged/retired more modules than these (mostly failed
+experiments) but they are not worth mentioning here because nobody else seems to
+have used them.
 
 Note that you can always get these retired modules from BackPAN or GitHub (I
 don't purge most of the repos) if needed.
@@ -87,7 +90,7 @@ don't purge most of the repos) if needed.
 
 =item * L<Data::Schema>
 
-Superseded by C<Data::Sah> since 2012.
+I wrote C<Data::Sah> which superseded this module since 2012.
 
 
 Alternate modules: L<Data::Sah>
@@ -103,8 +106,9 @@ Alternate modules: L<Devel::Confess>
 
 =item * L<Passwd::Unix::Alt>
 
-Abandoned this fork of C<Passwd::Unix> due to a couple of fundamental issues and
-superseded by C<Unix::Passwd::File> which is a clean-slate attempt.
+I first wrote C<Passwd::Unix::Alt> (a fork of C<Passwd::Unix>) to support shadow
+passwd/group files, but later abandoned this fork due to a couple of fundamental
+issues and later wrote a clean-slate attempt C<Unix::Passwd::File>.
 
 
 Alternate modules: L<Unix::Passwd::File>
